@@ -3,6 +3,7 @@ import typing
 from typing import List
 
 import aiohttp as aiohttp
+from aiohttp import ContentTypeError
 
 from southern_company_api.account import Account
 
@@ -12,6 +13,7 @@ from .exceptions import (
     CantReachSouthernCompany,
     InvalidLogin,
     NoJwtTokenFound,
+    NoRequestTokenFound,
     NoScTokenFound,
 )
 
@@ -30,6 +32,8 @@ async def get_request_verification_token() -> str:
             matches = re.findall(r'data-aft="(\S+)"', login_page)
     except Exception as error:
         raise CantReachSouthernCompany() from error
+    if len(matches) < 1:
+        raise NoRequestTokenFound()
     return matches[0]
 
 
@@ -60,7 +64,7 @@ class SouthernCompanyAPI:
     async def _get_sc_web_token(self) -> str:
         """Gets a sc_web_token which we get from a successful log in"""
         if self.request_token is None:
-            await get_request_verification_token()
+            self.request_token = await get_request_verification_token()
         headers = {
             "Content-Type": "application/json; charset=utf-8",
             "RequestVerificationToken": self.request_token,
@@ -77,9 +81,15 @@ class SouthernCompanyAPI:
             async with session.post(
                 "https://webauth.southernco.com/api/login", json=data, headers=headers
             ) as response:
-                connection = await response.json()
-        if connection["statusCode"] == 500:
-            raise InvalidLogin()
+                print(response.status)
+                if response.status != 200:
+                    raise CantReachSouthernCompany()
+                try:
+                    connection = await response.json()
+                except ContentTypeError as err:
+                    raise InvalidLogin from err
+                if connection["statusCode"] == 500:
+                    raise InvalidLogin()
         sc_regex = re.compile(r"NAME='ScWebToken' value='(\S+.\S+.\S+)'", re.IGNORECASE)
         sc_data = sc_regex.search(connection["data"]["html"])
         if sc_data and sc_data.group(1):
@@ -92,7 +102,7 @@ class SouthernCompanyAPI:
 
     async def _get_southern_jwt_cookie(self) -> str:
         if self.sc is None:
-            await self._get_sc_web_token()
+            self.sc = await self._get_sc_web_token()
         data = {"ScWebToken": self.sc}
         async with aiohttp.ClientSession() as session:
             async with session.post(
